@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2020 IBM Corporation.
+ * Copyright (c) 2017, 2021 IBM Corporation.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -418,7 +418,20 @@ public class Java9ElementsTests extends TestCase {
 	}
 	public void testBug535819() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTest(compiler, MODULE_PROC, "testBug535819", null, "bug535819", true);
+		internalTest(compiler, MODULE_PROC, "testBug535819", null, "bug535819", true, null);
+	}
+	public void testBug572673() throws IOException {
+		if (!canRunJava17()) {
+			return;
+		}
+		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
+		final String autoModuleJar = BatchTestUtils.setupProcessorJar("lib/lib.x.jar", BatchTestUtils._tmpFolder);
+		internalTest(compiler, MODULE_PROC, "testBug572673", null, "bug572673", true, 
+				(options) -> {
+					options.add("--module-path");
+					options.add(BatchTestUtils._jls8ProcessorJarPath + 
+							File.pathSeparator + autoModuleJar);
+				});
 	}
 	protected void internalTestWithBinary(JavaCompiler compiler, String processor, String compliance, String testMethod, String testClass, String resourceArea) throws IOException {
 		if (!canRunJava9()) {
@@ -478,9 +491,10 @@ public class Java9ElementsTests extends TestCase {
 		assertEquals("succeeded", System.getProperty(processor));
 	}
 	private void internalTest(JavaCompiler compiler, String processor, String testMethod, String testClass, String resourceArea) throws IOException {
-		internalTest(compiler, processor, testMethod, testClass, resourceArea, false);
+		internalTest(compiler, processor, testMethod, testClass, resourceArea, false, null);
 	}
-	private void internalTest(JavaCompiler compiler, String processor, String testMethod, String testClass, String resourceArea, boolean continueWithErrors) throws IOException {
+	private void internalTest(JavaCompiler compiler, String processor, String testMethod, String testClass, String resourceArea, 
+			boolean continueWithErrors, BatchTestUtils.InjectCustomOptions custom) throws IOException {
 		if (!canRunJava9()) {
 			return;
 		}
@@ -503,7 +517,7 @@ public class Java9ElementsTests extends TestCase {
 		PrintWriter printWriter = new PrintWriter(errBuffer);
 		TestDiagnosticListener diagnosticListener = new TestDiagnosticListener(printWriter);
 		if (continueWithErrors) {
-			BatchTestUtils.compileTreeWithErrors(compiler, options, targetFolder, diagnosticListener, true, true);
+			BatchTestUtils.compileTreeWithErrors(compiler, options, targetFolder, diagnosticListener, true, true, custom);
 		} else {
 			BatchTestUtils.compileTree(compiler, options, targetFolder, true);
 		}
@@ -556,7 +570,14 @@ public class Java9ElementsTests extends TestCase {
 		BatchTestUtils.compileInModuleMode(compiler, options, processor, srcRoot, null, true, binaryMode);
 		assertEquals("succeeded", System.getProperty(processor));
 	}
-	
+	public boolean canRunJava17() {
+		try {
+			SourceVersion.valueOf("RELEASE_17");
+		} catch(IllegalArgumentException iae) {
+			return false;
+		}
+		return true;
+	}
 	public boolean canRunJava9() {
 		try {
 			SourceVersion.valueOf("RELEASE_9");
