@@ -1555,4 +1555,31 @@ public class ScannerTest extends AbstractRegressionTest {
 		}
 		assertEquals("Wrong token type", ITerminalSymbols.TokenNameIntegerLiteral, token);
 	}
+
+	public void testBug575556_at_14() {
+		char[] source= "\"Hello\\sworld\"".toCharArray();
+		Scanner scanner = new Scanner(false, false, false, ClassFileConstants.JDK14, null, null, false);
+		scanner.setSource(source);
+		scanner.resetTo(0, source.length - 1);
+		try {
+			scanner.getNextToken();
+			fail("Should have rejected \\s");
+		} catch (InvalidInputException e) {
+			assertEquals(Scanner.INVALID_ESCAPE, e.getMessage());
+		}
+	}
+
+	public void testBug575556_at_15() {
+		char[] source= "\"Hello\\sworld\"".toCharArray();
+		Scanner scanner = new Scanner(false, false, false, ClassFileConstants.JDK15, null, null, false);
+		scanner.setSource(source);
+		scanner.resetTo(0, source.length - 1);
+		try {
+			int token = scanner.getNextToken();
+			assertEquals(TerminalTokens.TokenNameStringLiteral, token);
+			assertEquals("Unexpected string literal content", "Hello world", scanner.getCurrentStringLiteral());
+		} catch (InvalidInputException e) {
+			fail("Should have accepted \\s");
+		}
+	}
 }
