@@ -25,15 +25,16 @@ package org.eclipse.jdt.core.tests.compiler.regression;
 
 import java.util.ArrayList;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
+import org.eclipse.jdt.core.tests.compiler.util.HashtableOfObjectTest;
 import org.eclipse.jdt.core.tests.dom.StandAloneASTParserTest;
 import org.eclipse.jdt.core.tests.junit.extension.TestCase;
 import org.eclipse.jdt.core.tests.util.AbstractCompilerTest;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.flow.UnconditionalFlowInfo;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+
 /**
  * Run all compiler regression tests
  */
@@ -196,7 +197,7 @@ public static Test suite() {
 
 	 // add 15 specific test here (check duplicates)
 	 ArrayList since_15 = new ArrayList();
-	 since_15.add(ClassFileReaderTest_15.class);
+	 since_15.add(ClassFileReaderTest_17.class);
 	 since_15.add(JavadocTest_15.class);
 	 since_15.add(Unicode13Test.class);
 	 since_15.add(BatchCompilerTest_15.class);
@@ -204,19 +205,26 @@ public static Test suite() {
 
 	 // add 16 specific test here (check duplicates)
 	 ArrayList since_16 = new ArrayList();
-	 since_16.add(SealedTypesTests.class);
 	 since_16.add(LocalEnumTest.class);
 	 since_16.add(LocalStaticsTest.class);
 	 since_16.add(PreviewFeatureTest.class);
 	 since_16.add(ValueBasedAnnotationTests.class);
 	 since_16.add(BatchCompilerTest_16.class);
-	 since_16.add(RecordsRestrictedClassTest.class);
 	 since_16.add(PatternMatching16Test.class);
+	 since_16.add(RecordsRestrictedClassTest.class);
 	 since_16.add(JavadocTestForRecord.class);
 
+	 // add 17 specific test here (check duplicates)
+	 ArrayList since_17 = new ArrayList();
+	 since_17.add(SealedTypesTests.class);
+	 since_17.add(SwitchPatternTest.class);
+	 since_17.add(InstanceofPrimaryPatternTest.class);
+	 since_17.add(NullAnnotationTests17.class);
+
 	 // Build final test suite
 	TestSuite all = new TestSuite(TestAll.class.getName());
 	all.addTest(new TestSuite(StandAloneASTParserTest.class));
+	all.addTest(new TestSuite(HashtableOfObjectTest.class));
 	int possibleComplianceLevels = AbstractCompilerTest.getPossibleComplianceLevels();
 	if ((possibleComplianceLevels & AbstractCompilerTest.F_1_3) != 0) {
 		ArrayList tests_1_3 = (ArrayList)standardTests.clone();
@@ -391,6 +399,25 @@ public static Test suite() {
 		TestCase.resetForgottenFilters(tests_16);
 		all.addTest(AbstractCompilerTest.buildComplianceTestSuite(ClassFileConstants.getComplianceLevelForJavaVersion(ClassFileConstants.MAJOR_VERSION_16), tests_16));
 	}
+	if ((possibleComplianceLevels & AbstractCompilerTest.F_17) != 0) {
+		ArrayList tests_17 = (ArrayList)standardTests.clone();
+		tests_17.addAll(since_1_4);
+		tests_17.addAll(since_1_5);
+		tests_17.addAll(since_1_6);
+		tests_17.addAll(since_1_7);
+		tests_17.addAll(since_1_8);
+		tests_17.addAll(since_9);
+		tests_17.addAll(since_10);
+		tests_17.addAll(since_11);
+		tests_17.addAll(since_12);
+		tests_17.addAll(since_13);
+		tests_17.addAll(since_14);
+		tests_17.addAll(since_15);
+		tests_17.addAll(since_16);
+		tests_17.addAll(since_17);
+		TestCase.resetForgottenFilters(tests_17);
+		all.addTest(AbstractCompilerTest.buildComplianceTestSuite(ClassFileConstants.getComplianceLevelForJavaVersion(ClassFileConstants.MAJOR_VERSION_17), tests_17));
+	}
 	all.addTest(new TestSuite(Jsr14Test.class));
 	return all;
 }
