@@ -438,6 +438,9 @@ public class CompletionTestsRequestor2 extends CompletionRequestor {
 			case CompletionProposal.ANONYMOUS_CLASS_CONSTRUCTOR_INVOCATION :
 				buffer.append("ANONYMOUS_CLASS_CONSTRUCTOR_INVOCATION"); //$NON-NLS-1$
 				break;
+			case CompletionProposal.LAMBDA_EXPRESSION :
+				buffer.append("LAMBDA_EXPRESSION"); //$NON-NLS-1$
+				break;
 			default :
 				buffer.append("PROPOSAL"); //$NON-NLS-1$
 				break;
@@ -709,4 +712,8 @@ public class CompletionTestsRequestor2 extends CompletionRequestor {
 		}
 		return null;
 	}
+
+	public char[][] getExpectedTypesSignatures() {
+		return this.context.getExpectedTypesSignatures();
+	}
 }
