@@ -7,7 +7,6 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.rewrite.describing;
@@ -89,9 +88,12 @@ public class ASTRewritingTest extends AbstractJavaModelTests {
 	/** @deprecated using deprecated code */
 	private final static int JLS15_INTERNAL = AST.JLS15;
 
+	/** @deprecated using deprecated code */
 	private final static int JLS16_INTERNAL = AST.JLS16;
 
-	private final static int[] JLS_LEVELS = { JLS2_INTERNAL, JLS3_INTERNAL, JLS4_INTERNAL, JLS8_INTERNAL, JLS9_INTERNAL, JLS10_INTERNAL, JLS14_INTERNAL, JLS15_INTERNAL, JLS16_INTERNAL};
+	private final static int JLS17_INTERNAL = AST.JLS17;
+
+	private final static int[] JLS_LEVELS = { JLS2_INTERNAL, JLS3_INTERNAL, JLS4_INTERNAL, JLS8_INTERNAL, JLS9_INTERNAL, JLS10_INTERNAL, JLS14_INTERNAL, JLS15_INTERNAL, JLS16_INTERNAL, JLS17_INTERNAL};
 
 	private static final String ONLY_AST_STRING = "_only";
 	private static final String SINCE_AST_STRING = "_since";
@@ -136,6 +138,7 @@ public class ASTRewritingTest extends AbstractJavaModelTests {
 		  suite.addTest(ASTRewritingMoveCodeTest.suite());
 		  suite.addTest(ASTRewritingStatementsTest.suite());
 		  suite.addTest(ASTRewritingSwitchExpressionsTest.suite());
+		  suite.addTest(ASTRewritingSwitchPatternTest.suite());
 
 		  suite.addTest(ASTRewritingTrackingTest.suite());
 		  suite.addTest(ASTRewritingJavadocTest.suite());
@@ -245,6 +248,7 @@ public class ASTRewritingTest extends AbstractJavaModelTests {
 		setUpProjectAbove16();
 	}
 
+	@SuppressWarnings("deprecation")
 	protected void setUpProjectAbove16() throws Exception {
 		if (this.apiLevel == AST_INTERNAL_JLS16 ) {
 			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_16);
@@ -253,6 +257,14 @@ public class ASTRewritingTest extends AbstractJavaModelTests {
 		}
 	}
 
+	protected void setUpProjectAbove17() throws Exception {
+		if (this.apiLevel == AST_INTERNAL_JLS17 ) {
+			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_17);
+			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_17);
+			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_17);
+		}
+	}
+
 	protected IJavaProject createProject(String projectName, String complianceVersion) throws CoreException {
 		IJavaProject proj = createJavaProject(projectName, new String[] {"src"}, "bin");
 		proj.setOption(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR, JavaCore.SPACE);
