@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -480,6 +480,7 @@ public abstract class AbstractCommentParser implements JavadocTagConstants {
 	protected Object createReturnStatement() { return null; }
 	protected abstract void createTag();
 	protected abstract Object createTypeReference(int primitiveToken);
+	protected abstract Object createTypeReference(int primitiveToken, boolean canBeModule);
 	protected abstract Object createModuleTypeReference(int primitiveToken, int moduleRefTokenCount);
 
 	private int getIndexPosition() {
@@ -1115,7 +1116,9 @@ public abstract class AbstractCommentParser implements JavadocTagConstants {
 				prevToken = curToken;
 			}
 			if (stop) {
-				break;
+				if (parserKind != COMPLETION_PARSER) {
+					break;
+				}
 			}
 			int token = readTokenSafely();
 			curToken= token;
@@ -1259,7 +1262,7 @@ public abstract class AbstractCommentParser implements JavadocTagConstants {
 		if (moduleRefTokenCount > 0) {
 			return createModuleTypeReference(primitiveToken, moduleRefTokenCount);
 		}
-		return createTypeReference(primitiveToken);
+		return createTypeReference(primitiveToken, (allowModule && parsingJava15Plus));
 	}
 
 	protected boolean parseReference() throws InvalidInputException {
